@@ -9,12 +9,20 @@ Made with love by Bryan hu .
 
 The primitive functions to use. # API
 """
+from json import loads
+from pathlib import Path
+from random import randint
+from time import sleep
+from typing import Any
+from warnings import warn
+import httpx  # We probably should switch to aiohttp in the future
 import requests
 from bs4 import BeautifulSoup as bs
-from typing import Any
-import httpx  # We probably should switch to aiohttp in the future
-from time import sleep
-from random import randint
+
+# NOTE: This will need to be updated accordingly
+TEXT_REQUIREMENTS = loads(
+    Path(Path(Path(__file__).parent) / "txt_req.json").read_text()
+)
 
 
 def Search(
@@ -48,9 +56,9 @@ def Search(
         }
 
     """
-    # noqa
+
     def rget(site):
-        return requests.get(site, timeout=5,)
+        return requests.get(site, timeout=5)
 
     def _remove_dot_com(string: str) -> str:
         string = str(string)
@@ -68,39 +76,61 @@ def Search(
             )
         }
 
-    def s(content):
-        return bs(content.content, "lxml")
-
-    # TODO: Beautify this code
+    def s(t):
+        return bs(t.text, "lxml")
 
     search_on_site = _remove_dot_com(search_on_site)
-    TEXT_REQUIREMENTS = {"class": "post-text", "itemprop": "text"}
+
     if print_prog:
         print(f"Requesting results from {search_on_site}...")
+    # Fetches site
     r = rget(f"https://{search_on_site}.com/search?q={Query}")
-    r.raise_for_status()
+    try:
+        r.raise_for_status()
+    except requests.exceptions.HTTPError as e:
+        if "429" in str(e):
+            warn(
+                "Error: 429: You have reached the maximum number of requests t"
+                f"o {search_on_site}. Please try again later.",
+                RuntimeWarning,
+            )
+            return {}
     if print_prog:
         print("Parsing response HTML...")
     soup = s(r)
+
     if print_prog:
         print("Collecting question links...")
     questions = _find_questions(soup)
+
     if print_prog:
         print("Requesting questions found (This may take a while)...")
     _links_for_pages = []
     for link in map(
-        lambda x: f"https://{search_on_site}.com" + x, iter(questions.values())
+        lambda x: f"https://{search_on_site}.com{x}", iter(questions.values())
     ):
-        sleep(randint(1, 10) / 100)
+        sleep(randint(1, 10) / 100)  # We need to look like a human
         _links_for_pages.append(rget(link))
+
     if print_prog:
         print("Parsing questions found (This may take a while)...")
     pages = [  # Pages of all the questions related to Query
         s(link) for link in _links_for_pages
     ]
+
     if print_prog:
         print("Identifying question text...")
-    full_questions = [page.find(attrs=TEXT_REQUIREMENTS).get_text() for page in pages]
+    try:
+        full_questions = [
+            page.find(attrs=TEXT_REQUIREMENTS).get_text() for page in pages
+        ]
+    except AttributeError as e:
+        raise RuntimeError(
+            "Oh no! It appears that the StackOverflow's question text requirements "
+            "have changed. Please go to the Git repository and submit a pull request "
+            "to update the TEXT_REQUIREMENTS"
+            f"\n(Actual exception: {e})"
+        )
     if print_prog:
         print("Identifying answers...")
     answers = [
@@ -146,7 +176,7 @@ async def fSearch(
         }
 
     """
-    # noqa
+    # noqa: D202
     async def _remove_dot_com(string: str) -> str:
         string = str(string)
         # Maybe a regex is better here...
@@ -178,43 +208,64 @@ async def fSearch(
         return await client.get(site, timeout=5,)
 
     async def s(content):
-        return bs(content.content, "lxml")
+        return bs(content.text, "lxml")
 
     search_on_site = await _remove_dot_com(search_on_site)
-    TEXT_REQUIREMENTS = {"class": "post-text", "itemprop": "text"}
-    if print_prog:
-        print(f"Requesting results from {search_on_site}...")
+
     async with httpx.AsyncClient() as client:
-        # TODO: Clean this code
+        if print_prog:
+            print(f"Requesting results from {search_on_site}...")
         r = await rget(client, f"https://{search_on_site}.com/search?q={Query}")
-        r.raise_for_status()
+        try:
+            r.raise_for_status()
+        except requests.exceptions.HTTPError as e:
+            if "429" in str(e):
+                warn(
+                    "Error: 429: You have reached the maximum number of requests t"
+                    f"o {search_on_site}. Please try again later.",
+                    RuntimeWarning,
+                )
+                return {}
         if print_prog:
             print("Parsing response HTML...")
-        soup = bs(r.content, "lxml")
+        soup = await s(r)
+
         if print_prog:
             print("Collecting question links...")
         questions = await findQuestions(soup)
+
         if print_prog:
             print("Requesting questions found (This may take a while)...")
         _links_for_pages = []
         for link in map(
-            lambda x: f"https://{search_on_site}.com" + x, iter(questions.values())
+            lambda x: f"https://{search_on_site}.com{x}", iter(questions.values())
         ):
             sleep(randint(1, 10) / 100)
             _links_for_pages.append(await rget(client, link))
+
         if print_prog:
             print("Parsing questions found (This may take a while)...")
         pages = [  # Pages of all the questions related to Query
-            bs(link.content, "lxml") for link in _links_for_pages
+            await s(link) for link in _links_for_pages
         ]
+
         if print_prog:
             print("Identifying question text...")
-        full_questions = [
-            page.find(attrs=TEXT_REQUIREMENTS).get_text() for page in pages
-        ]
+        try:
+            full_questions = [
+                page.find(attrs=TEXT_REQUIREMENTS).get_text() for page in pages
+            ]
+        except AttributeError as e:
+            raise RuntimeError(
+                "Oh no! It appears that the StackOverflow's question text requirements "
+                "have changed. Please go to the Git repository and submit a pull request "
+                "to update the TEXT_REQUIREMENTS"
+                f"\n(Actual exception: {e})"
+            )
         if print_prog:
             print("Identifying answers...")
         answers = await findAnswers(pages)
+
         if print_prog:
             print("Returning results...")
         return dict(zip(full_questions, answers))
