@@ -20,9 +20,13 @@ from pprint import pprint
 from blessings import Terminal
 
 from . import __version__
-from .errors import UnknownError, UnsupportedPythonVersion
+from .errors import UnsupportedPythonVersion
 from .Search import Search, fSearch
 
+if not (sys.version_info.major >= 3 and sys.version_info.minor >= 8):
+    raise UnsupportedPythonVersion("This version of python is not supported (for now).")
+
+
 parser = argparse.ArgumentParser(
     prog="StackSearch",
     formatter_class=argparse.RawDescriptionHelpFormatter,
@@ -36,15 +40,10 @@ another python script, it'll return some parsable JSON. Assuming you are utilizi
 this script's wonderful functions and objects.""",
     epilog=' \n Judge a man by his questions rather than by his answers" - Voltaire \n ',
 )
-try:
-    parser.add_argument(  # Query
-        "query",
-        help="The query to search.",
-        nargs="*",
-        action="extend",
-    )
-except ValueError:
-    raise UnsupportedPythonVersion("This program only supports python 3.8 (for now).")
+
+parser.add_argument(  # Query
+    "query", help="The query to search.", nargs="*", action="extend",
+)
 parser.add_argument(  # JSON
     "-j",
     "--json",
@@ -73,16 +72,14 @@ parser.add_argument(  # Silent
     help="Don't print the progress.",
     dest="s",
 )
-try:
-    parser.add_argument(  # Sites
-        "--sites",
-        action="extend",
-        default=["stackoverflow"],
-        nargs="+",
-        help="The StackExchange sites to search.",
-    )
-except ValueError:
-    raise UnsupportedPythonVersion("This program only supports python 3.8 (for now).")
+
+parser.add_argument(  # Sites
+    "--sites",
+    action="extend",
+    default=["stackoverflow"],
+    nargs="+",
+    help="The StackExchange sites to search.",
+)
 parser.add_argument(  # Version
     "-v",
     "-V",
@@ -164,25 +161,22 @@ def custom_main(args_: list) -> None:
         parser.print_help(file=args.OUTPUT)
     else:
         PRINT_PROGRESS = not args.s
-        try:
-            SITES_TO_SEARCH = set(args.sites)
-        except TypeError:
-            raise UnknownError("This should never happen")
+
+        SITES_TO_SEARCH = set(args.sites)
         FILE = args.OUTPUT
         if PRINT_PROGRESS:
             print(f"Searching {', '.join(SITES_TO_SEARCH)}...")
         ANSWERS = []
-        try:
-            for site in map(str, SITES_TO_SEARCH):
-                ANSWERS.append(
-                    Search(
-                        " ".join(args.query),
-                        print_prog=PRINT_PROGRESS,
-                        search_on_site=site,
-                    )
+
+        for site in map(str, SITES_TO_SEARCH):
+            ANSWERS.append(
+                Search(
+                    " ".join(args.query),
+                    print_prog=PRINT_PROGRESS,
+                    search_on_site=site,
                 )
-        except TypeError as e:
-            raise e
+            )
+
         _cmd_line_stuff(ANSWERS, PRINT_PROGRESS, args, FILE)
 
 
@@ -206,28 +200,29 @@ async def fcustom_main(args_: list) -> None:
         parser.print_help(file=args.OUTPUT)
     else:
         PRINT_PROGRESS = not args.s
-        try:
-            SITES_TO_SEARCH = set(args.sites)
-        except TypeError:
-            raise UnknownError("This should never happen")
+
+        SITES_TO_SEARCH = set(args.sites)
         FILE = args.OUTPUT
         if PRINT_PROGRESS:
             print(f"Searching {', '.join(SITES_TO_SEARCH)}...")
         ANSWERS = []
-        try:
-            for site in map(str, SITES_TO_SEARCH):
-                ANSWERS.append(
-                    await fSearch(
-                        " ".join(args.query),
-                        print_prog=PRINT_PROGRESS,
-                        search_on_site=site,
-                    )
+
+        for site in map(str, SITES_TO_SEARCH):
+            ANSWERS.append(
+                await fSearch(
+                    " ".join(args.query),
+                    print_prog=PRINT_PROGRESS,
+                    search_on_site=site,
                 )
-        except TypeError as e:
-            raise e
+            )
 
         _cmd_line_stuff(ANSWERS, PRINT_PROGRESS, args, FILE)
 
 
-if __name__ == "__main__":
+def cli_main():
+    """The cli."""
     custom_main(sys.argv[1:])
+
+
+if __name__ == "__main__":
+    cli_main()
